import type { APIRoute } from 'astro';
import { API_SECRET } from 'astro:env/server';
import { z } from 'astro:schema';
import { db } from '@db/database.ts';

const postSchema = z.object({
  user: z.string(),
  killer: z.string().nullable(),
  message: z.string()
});

export const POST: APIRoute = async ({ request }) => {
  if (API_SECRET && request.headers.get('authorization') !== `Basic ${API_SECRET}`) {
    return new Response(null, { status: 401 });
  }

  let parsed;
  try {
    parsed = await postSchema.parseAsync(await request.json());
  } catch (_) {
    return new Response(null, { status: 400 });
  }

  let users;
  if (parsed.killer) {
    users = await db.getUsersByUuid({ uuid: [parsed.user, parsed.killer] });
  } else {
    users = await db.getUsersByUuid({ uuid: [parsed.user] });
  }
  const user = users[parsed.user];
  const killer = parsed.killer ? users[parsed.killer] : null;

  if (!user || (!killer && parsed.killer)) {
    return new Response(null, { status: 404 });
  }

  await db.addDeath({
    message: parsed.message,
    deadUserId: user.id,
    killerUserId: killer?.id
  });

  return new Response(null, { status: 200 });
};
